@@ -5,17 +5,17 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-servicecatalog",
-    "1.60.0",
+    "1.72.0",
     __name__[0:-6],
-    "aws-servicecatalog@1.60.0.jsii.tgz",
+    "aws-servicecatalog@1.72.0.jsii.tgz",
 )
 
 __all__ = [
